@@ -3,6 +3,7 @@ from collections import OrderedDict
 
 from django.forms import Media
 from django.utils.module_loading import autodiscover_modules
+from xprez.conf import settings
 
 
 class ContentTypeManager:
@@ -34,19 +35,18 @@ class ContentTypeManager:
             css = {"all": css}
         return Media(css=css, js=js)
 
-    def _collect_media(self, media_class_name, initial=Media()):
+    def _collect_media(self, media_class_name, initial=Media(), content_types=None):
         media = initial
-        for content in self._get_allowed_contents():
+        contents = self._get_allowed_contents(allowed_contents=content_types)
+        for content in contents:
             media += ContentTypeManager._get_class_media(content, media_class_name)
         return media
 
     def admin_media(self):
-        from .settings import XPREZ_JQUERY_INIT_MEDIA_JS
-
         return self._collect_media(
             "AdminMedia",
             initial=Media(
-                js=tuple(XPREZ_JQUERY_INIT_MEDIA_JS)
+                js=tuple(settings.XPREZ_JQUERY_INIT_MEDIA_JS)
                 + (
                     "xprez/admin/libs/jquery-sortable/source/js/jquery-sortable-min.js",
                     "xprez/admin/libs/jquery_ui/jquery-ui.min.js",
@@ -56,8 +56,8 @@ class ContentTypeManager:
             ),
         )
 
-    def front_media(self):
-        return self._collect_media("FrontMedia")
+    def front_media(self, content_types=None):
+        return self._collect_media("FrontMedia", content_types=content_types)
 
     def __init__(self):
         self._registry = OrderedDict()
@@ -74,13 +74,9 @@ class ContentTypeManager:
         excluded_contents=None,
     ):
         if allowed_contents is None:
-            from .settings import XPREZ_DEFAULT_ALLOWED_CONTENTS
-
-            allowed_contents = XPREZ_DEFAULT_ALLOWED_CONTENTS
+            allowed_contents = settings.XPREZ_DEFAULT_ALLOWED_CONTENTS
         if excluded_contents is None:
-            from .settings import XPREZ_DEFAULT_EXCLUDED_CONTENTS
-
-            excluded_contents = XPREZ_DEFAULT_EXCLUDED_CONTENTS
+            excluded_contents = settings.XPREZ_DEFAULT_EXCLUDED_CONTENTS
 
         content_types = []
         if allowed_contents == "__all__":
