@@ -1,4 +1,4 @@
-import sys
+import io
 import urllib
 
 from bs4 import BeautifulSoup
@@ -6,11 +6,6 @@ from django.template import Context, Template
 from django.utils.safestring import mark_safe
 from PIL import Image
 
-try:
-    import cStringIO
-except ImportError:
-    import io
-
 
 def _replace_wrapper_with_templatetag(wrapper, img, request):
     # wrapper and img may be the same tag - that is the case of inline images
@@ -19,10 +14,12 @@ def _replace_wrapper_with_templatetag(wrapper, img, request):
     if not src.lower().startswith("http") and request:
         src = request.build_absolute_uri(src)
 
-    if sys.version_info >= (3, 0):
-        file = io.BytesIO(urllib.request.urlopen(src).read())
-    else:
-        file = cStringIO.StringIO(urllib.urlopen(src).read())
+    request = urllib.request.Request(
+        src, headers={"User-agent": ""}  # needed for cloudflare
+    )
+
+    file = io.BytesIO(urllib.request.urlopen(request).read())
+
     im = Image.open(file)
     width, height = im.size
     classes = list(img.get("class", [])) + list(wrapper.get("class", []))
@@ -90,11 +87,7 @@ def parse_text(text_source, request):
     for tag in soup.find_all(attrs={"contenteditable": True}):
         del tag["contenteditable"]
 
-    if sys.version_info >= (3, 0):
-        text_parsed = str(soup)
-    else:
-        text_parsed = unicode(soup)
-    return text_parsed
+    return str(soup)
 
 
 def render_text_parsed(text_parsed, extra_context={}):
